[gnumeric] Tests: last test with its own corpus converted.



commit 0e52cbfda244955961f949e4ff0df02336670a35
Author: Morten Welinder <terra gnome org>
Date:   Sun Apr 12 14:26:34 2015 -0400

    Tests: last test with its own corpus converted.

 test/t6160-ods-deterministic.pl |   60 ++------------------------------------
 1 files changed, 4 insertions(+), 56 deletions(-)
---
diff --git a/test/t6160-ods-deterministic.pl b/test/t6160-ods-deterministic.pl
index 6f2131c..23492eb 100755
--- a/test/t6160-ods-deterministic.pl
+++ b/test/t6160-ods-deterministic.pl
@@ -10,62 +10,10 @@ use GnumericTest;
 my $format = "Gnumeric_OpenCalc:odf";
 my $unzip = &GnumericTest::find_program ("unzip");
 
-my @sources =
-    ("$samples/excel/address.xls",
-     "$samples/excel/bitwise.xls",
-     "$samples/excel/chart-tests-excel.xls",
-     # "$samples/excel/datefuns.xls", # uses NOW()
-     "$samples/excel/dbfuns.xls",
-     "$samples/excel/engfuns.xls",
-     "$samples/excel/finfuns.xls",
-     "$samples/excel/functions.xls",
-     "$samples/excel/infofuns.xls",
-     "$samples/excel/logfuns.xls",
-     "$samples/excel/lookfuns2.xls",
-     "$samples/excel/lookfuns.xls",
-     "$samples/excel/mathfuns.xls",
-     "$samples/excel/objs.xls",
-     "$samples/excel/operator.xls",
-     "$samples/excel/sort.xls",
-     "$samples/excel/statfuns.xls",
-     "$samples/excel/textfuns.xls",
-     "$samples/excel/yalta2008.xls",
-     "$samples/excel12/cellstyle.xlsx",
-     # Takes too long
-     # "$samples/crlibm.gnumeric",
-     "$samples/amath.gnumeric",
-     # Takes too long
-     # "$samples/gamma.gnumeric",
-     "$samples/linest.xls",
-     "$samples/vba-725220.xls",
-     "$samples/sumif.xls",
-     "$samples/array-intersection.xls",
-     "$samples/arrays.xls",
-     "$samples/ftest.xls",
-     "$samples/ttest.xls",
-     "$samples/chitest.xls",
-     "$samples/numbermatch.gnumeric",
-     "$samples/solver/afiro.mps",
-     "$samples/solver/blend.mps",
-     "$samples/auto-filter-tests.gnumeric",
-     "$samples/cell-comment-tests.gnumeric",
-     "$samples/colrow-tests.gnumeric",
-     "$samples/cond-format-tests.gnumeric",
-     "$samples/formula-tests.gnumeric",
-     "$samples/graph-tests.gnumeric",
-     "$samples/merge-tests.gnumeric",
-     "$samples/names-tests.gnumeric",
-     "$samples/number-tests.gnumeric",
-     "$samples/page-setup-tests.gnumeric",
-     "$samples/rich-text-tests.gnumeric",
-     "$samples/sheet-formatting-tests.gnumeric",
-     "$samples/solver-tests.gnumeric",
-     "$samples/split-panes-tests.gnumeric",
-     "$samples/string-tests.gnumeric",
-     "$samples/merge-tests.gnumeric",
-     "$samples/style-tests.gnumeric",
-     "$samples/validation-tests.gnumeric",
-    );
+my @sources = &GnumericTest::corpus();
+# datefuns and docs-samples use NOW(); the rest takes too long.
+ sources = grep { !m{(^|/)(datefuns\.xls|(docs-samples|crlibm|gamma)\.gnumeric)$} } @sources;
+
 my $nskipped = 0;
 my $ngood = 0;
 my $nbad = 0;


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]